@@ -44,7 +44,7 @@ if [ -f $RUNFILE ]
 if [ "$1" = "lan" ] ; then
 #start-stop-daemon -S -p $RUNFILE -m -b -x $DNSMASQ -- -k -I lo -z -a $IP_ADDR -F $DHCP_RANGE1,$DHCP_RANGE2 -b
 #start-stop-daemon -S -p $RUNFILE -m -b -x $DNSMASQ -- -k -i wlan0 -I lo -z -a $IP_ADDR --address=/#/$IP_ADDR -F $DHCP_RANGE1,$DHCP_RANGE2,h6
-start-stop-daemon -S -p $RUNFILE -m -b -x $DNSMASQ --  -z -R -i wlan0 -I lo -h -5 -p 0 -F $DHCP_RANGE1,$DHCP_RANGE2,9999h --dhcp-option=6 --dhcp-option=3
+start-stop-daemon -S -p $RUNFILE -m -b -x $DNSMASQ --  -z -R -i wlan0 -I lo -h -5 -p 0 -x $RUNFILE -F $DHCP_RANGE1,$DHCP_RANGE2,9999h --dhcp-option=6 --dhcp-option=3
 fi
 
 if [ "$1" = "for" ] ; then
