@@ -1,5 +1,6 @@
 #include "pwqdialog.h"
 #include "ui_pwqdialog.h"
+#include <QMaemo5InformationBox>
 #include <pwd.h>
 //#include <crypt.h>
 
@@ -20,10 +21,14 @@ void PWQDialog::pwCheck()
 {
     struct passwd *p;
     p=getpwnam("root");
-    QString test=ui->lineEdit->text();
+    //QString test=ui->lineEdit->text();
     QString check;
-    check=((char*)crypt(test.toStdString().c_str(),p->pw_passwd));
+    check=((char*)crypt(ui->lineEdit->text().toStdString().c_str(),p->pw_passwd));
     if ( check.contains(p->pw_passwd) )
         this->accept();
-    else this->reject(); //reject
+    else
+    {
+        QMaemo5InformationBox::information(this, "wrong password!",QMaemo5InformationBox::NoTimeout);
+        this->reject(); //reject
+    }
 }
