@@ -1,5 +1,6 @@
 #!/bin/sh
-/sbin/ifdown usb0
+#/sbin/ifdown usb0
+ifconfig usb0 0.0.0.0 down
 kill `cat /var/run/usb_tethering.pid`
 rm /var/run/usb_tethering.pid
 run-standalone.sh dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:'USB Deactivated'
